# rmtoo

NAME
DESCRIPTION
NOTE
IDEA
IMPLEMENTATION
CONFIGURATION
SEE ALSO
AUTHOR
COPYRIGHT

## NAME

rmtoo-analytics - requirements management tool: analytics modules

## DESCRIPTION

The rmtoo package can check some different aspects of requirements properties. The tool has some built in heuristics to decide if a requirement or topic is a good or a bad one.

## NOTE

The analytics modules must be seen as alpha. A lot of research and statistics must be done to get a stable and usable version of the analytics modules.

Nevertheless the currently implemented measurements and heuristics may lead to hints for better requirements and topics.

## IDEA

It is mostly impossible to decide whether a requirement is a good one. A lot of things must be known; mostly even the expertise in the described topic is needed for a decision.

But it is often easy to decide, that a requirement is a bad one. Bad requirements contain words like approximately or perhaps. Even words like or or and typically render a requirement as bad. A requirements which is longer than some ten words or than one sentence is typically also not a good requirement.

## IMPLEMENTATION

The analytics modules are called after the requirements and topics are read in and parsed. It is configurable if rmtoo should stop if it finds problems or not.

## CONFIGURATION

The analytics configuration entry is responsible for handling the analytics modules. It is a dictionary.

All analytic modules work on one all topic sets (see rmtoo-config(5) for more details). All analytic modules also work on one set of topics.

The configuration key stop_on_errors specifies if rmtoo should stop when a possible problem was detected.

It might be possible that analytic modules support other configuration options. Please consult the appropriate man pages.

Example specification section:

"processing": {
"analytics": {
"stop_on_errors": false
}
}

## SEE ALSO

rmtoo(7) - overview of rmtoo including all references to available documentation.

## AUTHOR

Written by Andreas Florath (rmtoo@florath.net)

## COPYRIGHT

Copyright © 2010 by flonatel (rmtoo@florath.net). License GPLv3+: GNU GPL version 3 or later